@@ -1,6 +1,4 @@
-"""
-Configuration file for the Sphinx documentation builder.
-"""
+"""Configuration file for the Sphinx documentation builder."""
 # -- stdlib imports ------------------------------------------------------------
 import importlib
 import sys
